@@ -2,6 +2,7 @@
 # Copyright 2016 - Brocade Communications Systems, Inc.
 # Copyright 2018 - Extreme Networks, Inc.
 # Copyright 2019 - Nokia Networks
+# Copyright 2022 - NetCracker Technology Corp.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -26,6 +27,7 @@ from keystoneauth1 import loading
 from oslo_config import cfg
 from oslo_log import log
 from oslo_middleware import cors
+from oslo_policy import opts
 from osprofiler import opts as profiler
 
 from mistral import version
@@ -63,6 +65,29 @@ auth_type_opt = cfg.StrOpt(
     help=_('Authentication type (valid options: keystone, keycloak-oidc)')
 )
 
+action_providers_opts = [
+    cfg.ListOpt(
+        'allowlist',
+        default=[],
+        help=_(
+            'Allowlist with action providers that is allowed to be '
+            'loaded from the entry point "mistral.action.providers", '
+            'if empty all action providers will be allowed unless '
+            'denylist is set.'
+        ),
+    ),
+    cfg.ListOpt(
+        'denylist',
+        default=[],
+        help=_(
+            'Denylist with action providers that is not allowed to '
+            'be loaded from the entry point "mistral.action.providers", '
+            'allowlist takes precendence, if empty all action providers '
+            'will be allowed.'
+        ),
+    ),
+]
+
 legacy_action_provider_opts = [
     cfg.BoolOpt(
         'load_action_plugins',
@@ -90,6 +115,25 @@ legacy_action_provider_opts = [
             'This property is needed mostly for testing.'
         )
     ),
+    cfg.ListOpt(
+        'allowlist',
+        default=[],
+        help=_(
+            'Allowlist with actions that is allowed to be '
+            'loaded from the entry point "mistral.actions", '
+            'if empty all actions will be allowed.'
+        ),
+    ),
+    cfg.ListOpt(
+        'denylist',
+        default=[],
+        help=_(
+            'Denylist with actions that is not allowed to '
+            'be loaded from the entry point "mistral.actions", '
+            'allowlist takes precedence, if empty all actions '
+            'will be allowed.'
+        ),
+    ),
 ]
 
 api_opts = [
@@ -127,7 +171,19 @@ api_opts = [
                "turned off in the API request. 'disabled' disables validation "
                "for all API requests. 'mandatory' enables validation for all "
                "API requests.")
-    )
+    ),
+    cfg.BoolOpt(
+        'enable_info_endpoint',
+        default=False,
+        help=_('Enable API for exposing info json about '
+               'current Mistral build.')
+    ),
+    cfg.StrOpt(
+        'info_json_file_path',
+        default='info.json',
+        help=_("Specify the path to info json file which will be "
+               "exposed via /info endpoint.")
+    ),
 ]
 
 js_impl_opt = cfg.StrOpt(
@@ -248,6 +304,13 @@ engine_opts = [
             'to start subworkflow via RPC to improve load balancing '
             'in case of several engine instances.'
         )
+    ),
+    cfg.StrOpt(
+        'merge_strategy',
+        choices=['replace', 'merge'],
+        default="replace",
+        help=_('Merge strategy of data inside workflow execution. '
+               '(replace, merge)')
     )
 ]
 
@@ -525,14 +588,65 @@ action_heartbeat_opts = [
     )
 ]
 
+action_logging_opts = [
+    cfg.BoolOpt(
+        'hide_response_body',
+        default=False,
+        help=(
+            'If this value is set to True then HTTP action response '
+            'body will be hidden in logs.'
+        )
+    ),
+    cfg.BoolOpt(
+        'hide_request_body',
+        default=False,
+        help=(
+            'If this value is set to True then HTTP action request '
+            'body will be hidden in logs.'
+        )
+    ),
+    cfg.ListOpt(
+        'sensitive_headers',
+        default=[],
+        help='List of sensitive headers that should be hidden in logs.'
+    )
+]
+
+context_versioning_opts = [
+    cfg.BoolOpt(
+        'enabled',
+        default=True,
+        help=(
+            'If this value is set to True then Mistral will use '
+            'versioning of context to improve results of context '
+            'merging. This feature fixes some bugs with context merging '
+            'but also slows down Mistral performance.'
+        )
+    ),
+    cfg.BoolOpt(
+        'hash_version_keys',
+        default=True,
+        help=(
+            'If this value is set to True then Mistral will use '
+            'md5 hashing for version keys to ensure this keys will be '
+            'the same size. Disabling hashing could be useful for debug '
+            'purposes, but avoid this in production, because it leads to '
+            'excessive memory consumption.'
+        )
+    )
+]
+
 coordination_opts = [
     cfg.StrOpt(
         'backend_url',
+        secret=True,
         help=_('The backend URL to be used for coordination')
     ),
     cfg.FloatOpt(
         'heartbeat_interval',
         default=5.0,
+        deprecated_for_removal=True,
+        deprecated_reason='This option has been unused and has had no effect',
         help=_('Number of seconds between heartbeats for coordination.')
     )
 ]
@@ -672,8 +786,20 @@ yaql_opts = [
     )
 ]
 
+
+healthcheck_opts = [
+    cfg.BoolOpt('enabled',
+                default=False,
+                help=_('Enable the health check endpoint at /healthcheck. '
+                       'Note that this is unauthenticated. More information '
+                       'is available at '
+                       'https://docs.openstack.org/oslo.middleware/latest/'
+                       'reference/healthcheck_plugins.html.')),
+]
+
 CONF = cfg.CONF
 
+ACTION_PROVIDERS_GROUP = 'action_providers'
 LEGACY_ACTION_PROVIDER_GROUP = 'legacy_action_provider'
 API_GROUP = 'api'
 ENGINE_GROUP = 'engine'
@@ -686,9 +812,12 @@ PECAN_GROUP = 'pecan'
 COORDINATION_GROUP = 'coordination'
 EXECUTION_EXPIRATION_POLICY_GROUP = 'execution_expiration_policy'
 ACTION_HEARTBEAT_GROUP = 'action_heartbeat'
+ACTION_LOGGING_GROUP = 'action_logging'
+CONTEXT_VERSIONING_GROUP = 'context_versioning'
 PROFILER_GROUP = profiler.list_opts()[0][0]
 KEYCLOAK_OIDC_GROUP = "keycloak_oidc"
 YAQL_GROUP = "yaql"
+HEALTHCHECK_GROUP = 'healthcheck'
 KEYSTONE_GROUP = "keystone"
 
 
@@ -701,6 +830,7 @@ CONF.register_opt(rpc_response_timeout_opt)
 CONF.register_opt(oslo_rpc_executor)
 CONF.register_opt(expiration_token_duration)
 
+CONF.register_opts(action_providers_opts, group=ACTION_PROVIDERS_GROUP)
 CONF.register_opts(
     legacy_action_provider_opts,
     group=LEGACY_ACTION_PROVIDER_GROUP
@@ -718,6 +848,8 @@ CONF.register_opts(
     action_heartbeat_opts,
     group=ACTION_HEARTBEAT_GROUP
 )
+CONF.register_opts(action_logging_opts, group=ACTION_LOGGING_GROUP)
+CONF.register_opts(context_versioning_opts, group=CONTEXT_VERSIONING_GROUP)
 CONF.register_opts(event_engine_opts, group=EVENT_ENGINE_GROUP)
 CONF.register_opts(notifier_opts, group=NOTIFIER_GROUP)
 CONF.register_opts(pecan_opts, group=PECAN_GROUP)
@@ -725,6 +857,7 @@ CONF.register_opts(coordination_opts, group=COORDINATION_GROUP)
 CONF.register_opts(profiler_opts, group=PROFILER_GROUP)
 CONF.register_opts(keycloak_oidc_opts, group=KEYCLOAK_OIDC_GROUP)
 CONF.register_opts(yaql_opts, group=YAQL_GROUP)
+CONF.register_opts(healthcheck_opts, group=HEALTHCHECK_GROUP)
 loading.register_session_conf_options(CONF, KEYSTONE_GROUP)
 
 CLI_OPTS = [
@@ -759,6 +892,8 @@ _DEFAULT_LOG_LEVELS = [
 
 def list_opts():
     return [
+        (ACTION_PROVIDERS_GROUP, action_providers_opts),
+        (LEGACY_ACTION_PROVIDER_GROUP, legacy_action_provider_opts),
         (API_GROUP, api_opts),
         (ENGINE_GROUP, engine_opts),
         (EXECUTOR_GROUP, executor_opts),
@@ -772,7 +907,10 @@ def list_opts():
         (PROFILER_GROUP, profiler_opts),
         (KEYCLOAK_OIDC_GROUP, keycloak_oidc_opts),
         (YAQL_GROUP, yaql_opts),
+        (HEALTHCHECK_GROUP, healthcheck_opts),
         (ACTION_HEARTBEAT_GROUP, action_heartbeat_opts),
+        (ACTION_LOGGING_GROUP, action_logging_opts),
+        (CONTEXT_VERSIONING_GROUP, context_versioning_opts),
         (None, default_group_opts)
     ]
 
@@ -796,6 +934,10 @@ def parse_args(args=None, usage=None, default_config_files=None):
 def set_config_defaults():
     """This method updates all configuration default values."""
     set_cors_middleware_defaults()
+    # TODO(gmann): Remove setting the default value of config policy_file
+    # once oslo_policy change the default value to 'policy.yaml'.
+    # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+    opts.set_defaults(CONF, 'policy.yaml')
 
 
 def set_cors_middleware_defaults():
