@@ -184,6 +184,9 @@ class Action(object, metaclass=abc.ABCMeta):
                 'project_id': security.get_project_id(),
             })
 
+        LOG.info("Create action execution [action_name=%s, action_ex_id=%s]",
+                 self.action_desc.name, action_ex_id)
+
         self.action_ex = db_api.create_action_execution(values)
 
         if self.task_ex:
@@ -198,10 +201,12 @@ class Action(object, metaclass=abc.ABCMeta):
         if prev_state != state:
             wf_trace.info(
                 None,
-                "Action '%s' (%s)(task=%s) [%s -> %s, %s]" %
+                "Action '%s' (%s)(task_name=%s, "
+                "task_ex_id=%s) [%s -> %s, %s]" %
                 (self.action_ex.name,
                  self.action_ex.id,
                  self.task_ex.name if self.task_ex else None,
+                 self.task_ex.id if self.task_ex else None,
                  prev_state,
                  state,
                  result.cut_repr())
